; ******************************************************************************
; *  Kindermann                                             Schuljahr 2016/17  *
; *                                                                            *
; *                            AVR-Flashtool 1.6                               *
; *                                                                            *
; *                   Windows-Installer fr 32 und 64 Bit                      *
; *                                                                            *
; ******************************************************************************


;Use modern interface
!include MUI2.nsh

;Include LogicLib
!include LogicLib.nsh

;Include WinMessages
!include WinMessages.nsh

;Include installations on x64 machines
!include "x64.nsh"

;Include Winver
!include "winver.nsh"

;Compressor
SetCompressor lzma

;MUI Settings
!define MUI_ICON "avrflashtool_setup.ico"
!define MUI_UNICON "avrflashtool_setup.ico"

; The default installation directory
InstallDir "$PROGRAMFILES\AVR-Flashtool"

; Registry key to check for directory (so if you install again, it will
; overwrite the old one automatically)
InstallDirRegKey HKLM "Software\AVR-Flashtool" "Install_Dir"

;Variables
Var StartMenuFolder

;Interface Settings
!define MUI_ABORTWARNING

;Pages
!insertmacro MUI_PAGE_WELCOME
!insertmacro MUI_PAGE_LICENSE "./LICENSE.txt"
!insertmacro MUI_PAGE_COMPONENTS
!insertmacro MUI_PAGE_DIRECTORY

;Start Menu Folder Page Configuration
!define MUI_STARTMENUPAGE_REGISTRY_ROOT "HKCU"
!define MUI_STARTMENUPAGE_REGISTRY_KEY "Software\AVR-Flashtool"
!define MUI_STARTMENUPAGE_REGISTRY_VALUENAME "Start Menu Folder"

!insertmacro MUI_PAGE_STARTMENU Application $StartMenuFolder
!insertmacro MUI_PAGE_INSTFILES
!insertmacro MUI_UNPAGE_CONFIRM
!insertmacro MUI_UNPAGE_INSTFILES

;Languages
!insertmacro MUI_LANGUAGE "German"
;MUI end

;Name
Name "AVR-Flashtool"

;Branding Text
BrandingText " Dietrich Kindermann 2015"

;the file to write
OutFile "avrflashtool_1.6_win7_setup.exe"

ShowInstDetails show
ShowUnInstDetails show

;functions and macros

;macro ShellExecWait
!macro ShellExecWait verb app param workdir show exitoutvar ;only app and show must be != "", every thing else is optional
  #define SEE_MASK_NOCLOSEPROCESS 0x40
  System::Store S
  System::Call '*(&i60)i.r0'
  System::Call '*$0(i 60,i 0x40,i $hwndparent,t "${verb}",t $\'${app}$\',t $\'${param}$\',t "${workdir}",i ${show})i.r0'
  System::Call 'shell32::ShellExecuteEx(ir0)i.r1 ?e'
  ${If} $1 <> 0
	System::Call '*$0(is,i,i,i,i,i,i,i,i,i,i,i,i,i,i.r1)' ;stack value not really used, just a fancy pop ;)
	System::Call 'kernel32::WaitForSingleObject(ir1,i-1)'
	System::Call 'kernel32::GetExitCodeProcess(ir1,*i.s)'
	System::Call 'kernel32::CloseHandle(ir1)'
  ${EndIf}
  System::Free $0
	!if "${exitoutvar}" == ""
	pop $0
	!endif
  System::Store L
	!if "${exitoutvar}" != ""
	pop ${exitoutvar}
	!endif
!macroend

;StrContains
;This function does a case sensitive searches for an occurrence of a substring in a string. 
;It returns the substring if it is found. 
;Otherwise it returns null(""). 
;Written by kenglish_hi
;Adapted from StrReplace written by dandaman32
  
  Var STR_HAYSTACK
  Var STR_NEEDLE
  Var STR_CONTAINS_VAR_1
  Var STR_CONTAINS_VAR_2
  Var STR_CONTAINS_VAR_3
  Var STR_CONTAINS_VAR_4
  Var STR_RETURN_VAR

;function string contains
Function StrContains
  Exch $STR_NEEDLE
  Exch 1
  Exch $STR_HAYSTACK
  ;Uncomment to debug
  ;MessageBox MB_OK 'STR_NEEDLE = $STR_NEEDLE STR_HAYSTACK = $STR_HAYSTACK '
  StrCpy $STR_RETURN_VAR ""
  StrCpy $STR_CONTAINS_VAR_1 -1
  StrLen $STR_CONTAINS_VAR_2 $STR_NEEDLE
  StrLen $STR_CONTAINS_VAR_4 $STR_HAYSTACK
  loop:
    IntOp $STR_CONTAINS_VAR_1 $STR_CONTAINS_VAR_1 + 1
    StrCpy $STR_CONTAINS_VAR_3 $STR_HAYSTACK $STR_CONTAINS_VAR_2 $STR_CONTAINS_VAR_1
    StrCmp $STR_CONTAINS_VAR_3 $STR_NEEDLE found
    StrCmp $STR_CONTAINS_VAR_1 $STR_CONTAINS_VAR_4 done
    Goto loop
  found:
    StrCpy $STR_RETURN_VAR $STR_NEEDLE
    Goto done
  done:
  Pop $STR_NEEDLE ;Prevent "invalid opcode" errors and keep the
  Exch $STR_RETURN_VAR  
FunctionEnd

;macro string contains  
!macro _StrContainsConstructor OUT NEEDLE HAYSTACK
  Push `${HAYSTACK}`
  Push `${NEEDLE}`
  Call StrContains
  Pop `${OUT}`
!macroend
 
!define StrContains '!insertmacro "_StrContainsConstructor"'


Function FileReadUnicode
	Push $0
	Exch 
	Pop $0 ; handle
	Push $1
	Push $2
	Push $3
	Push $4
 
	IntOp $4 0 + 0
	IntOp $3 0 + 0
	StrCpy $1 ""
	SetErrorLevel 0
read:	
	FileReadByte $0 $2
	IntCmp $4 0 0 skip skip
	IntCmp $2 0x0a skip 0 0 
	IntCmp $2 0x0d readsecondhalf 0 0 
	IntCmp $2 0 done 0 0
	IntFmt $2 "%c" $2
	StrCpy $1 "$1$2"
skip:	
	IntOp $4 $4 + 1
	IntOp $4 $4 % 2
	Goto read
readsecondhalf:	
	FileReadByte $0 $2
done:	
	Pop $4
	Pop $3
	Pop $2
	Push $1
	Exch 
	Pop $1
	Exch 
	Pop $0
FunctionEnd


Function RemoveDriver
  FindFirst $1 $2 "$WINDIR\inf\oem*.inf"
  loop:
    IfErrors end
	FileOpen $R0 "$WINDIR\inf\$2" r
	Push $R0
	Call FileReadUnicode	
	Pop $R1
	IfErrors done
	StrCpy $R1 $R1 27 3
	StrCpy $R2 "micronucleus_bootloader.inf"
	StrCpy $R2 $R2 27 0	
    ${If} $R1 == $R2
      DetailPrint "$WINDIR\inf\$2 wird deinstalliert."
     !insertmacro ShellExecWait "" '"$INSTDIR\Treiber\instdrv.exe"' '"remove" "$INSTDIR\Treiber\micronucleus_bootloader.inf" "USB\VID_16D0&PID_0753"' "" ${SW_SHOWMINIMIZED}" $3
     !insertmacro ShellExecWait "" '"$INSTDIR\Treiber\instdrv.exe"' '"dp_delete" "$2"' "" ${SW_SHOWMINIMIZED}" $3
    ${EndIf}	
  	StrCpy $R1 $R1 14 0
	StrCpy $R2 "AVRUSBBoot.inf"
	StrCpy $R2 $R2 14 0	
    ${If} $R1 == $R2
      DetailPrint "$WINDIR\inf\$2 wird deinstalliert."
      !insertmacro ShellExecWait "" '"$INSTDIR\Treiber\instdrv.exe"' '"remove" "$INSTDIR\Treiber\AVRUSBBoot.inf" "USB\VID_16C0&PID_05DC"' "" ${SW_SHOWMINIMIZED}" $3
      !insertmacro ShellExecWait "" '"$INSTDIR\Treiber\instdrv.exe"' '"dp_delete" "$2"' "" ${SW_SHOWMINIMIZED}" $3
    ${EndIf}
  done:   
  FindNext $1 $2
  FileClose $R0
  Goto loop  
  end:
  FindClose $1
  FindFirst $1 $2 "$WINDIR\inf\*.*"
  dirloop:
     IfErrors dirend 
     FindNext $1 $2
     goto dirloop
  dirend:
  FindClose $1  
FunctionEnd


Function DeleteDriver
  FindFirst $1 $2 "$WINDIR\inf\oem*.inf"
  loop:
    IfErrors end
	StrCpy $R3 0
	FileOpen $R0 "$WINDIR\inf\$2" r
	Push $R0
	Call FileReadUnicode	
	Pop $R1
	IfErrors done
	StrCpy $R1 $R1 27 3
	StrCpy $R2 "micronucleus_bootloader.inf"
	StrCpy $R2 $R2 27 0	
    ${If} $R1 == $R2
      StrCpy $3 $2
	  StrLen $R3 $2
	  IntOp $R3 $R3 - 3
	  StrCpy $2 $2 $R3 0
	  StrCpy $4 "$2PNF"
	${EndIf}
	StrCpy $R1 $R1 14 0
	StrCpy $R2 "AVRUSBBoot.inf"
	StrCpy $R2 $R2 14 0	
    ${If} $R1 == $R2
	  StrCpy $3 $2
	  StrLen $R3 $2
	  IntOp $R3 $R3 - 3
	  StrCpy $2 $2 $R3 0
	  StrCpy $4 "$2PNF"	  
	${EndIf}
	done:   
  FileClose $R0
  ${If} $R3 > 0  
  DetailPrint "Lsche Treiberdateien ..."
  Delete $WINDIR\inf\$3
  Delete $WINDIR\inf\$4
  ${EndIf}
  FindNext $1 $2
  Goto loop  
  end:
  FindClose $1
  FindFirst $1 $2 "$WINDIR\inf\*.*"
  dirloop:
     IfErrors dirend 
     FindNext $1 $2
     goto dirloop
  dirend:
  FindClose $1  
FunctionEnd


Function un.FileReadUnicode
	Push $0
	Exch 
	Pop $0 ; handle
	Push $1
	Push $2
	Push $3
	Push $4
 
	IntOp $4 0 + 0
	IntOp $3 0 + 0
	StrCpy $1 ""
	SetErrorLevel 0
read:	
	FileReadByte $0 $2
	IntCmp $4 0 0 skip skip
	IntCmp $2 0x0a skip 0 0 
	IntCmp $2 0x0d readsecondhalf 0 0 
	IntCmp $2 0 done 0 0
	IntFmt $2 "%c" $2
	StrCpy $1 "$1$2"
skip:	
	IntOp $4 $4 + 1
	IntOp $4 $4 % 2
	Goto read
readsecondhalf:	
	FileReadByte $0 $2
done:	
	Pop $4
	Pop $3
	Pop $2
	Push $1
	Exch 
	Pop $1
	Exch 
	Pop $0
FunctionEnd


Function un.RemoveDriver
  FindFirst $1 $2 "$WINDIR\inf\oem*.inf"
  loop:
    IfErrors end
	FileOpen $R0 "$WINDIR\inf\$2" r
	Push $R0
	Call un.FileReadUnicode	
	Pop $R1
	IfErrors done
	StrCpy $R1 $R1 27 3
	StrCpy $R2 "micronucleus_bootloader.inf"
	StrCpy $R2 $R2 27 0	
    ${If} $R1 == $R2
      DetailPrint "$WINDIR\inf\$2 wird deinstalliert."
     !insertmacro ShellExecWait "" '"$INSTDIR\Treiber\instdrv.exe"' '"remove" "$INSTDIR\Treiber\micronucleus_bootloader.inf" "USB\VID_16D0&PID_0753"' "" ${SW_SHOWMINIMIZED}" $3
     !insertmacro ShellExecWait "" '"$INSTDIR\Treiber\instdrv.exe"' '"dp_delete" "$2"' "" ${SW_SHOWMINIMIZED}" $3
    ${EndIf}
	StrCpy $R1 $R1 14 0
	StrCpy $R2 "AVRUSBBoot.inf"
	StrCpy $R2 $R2 14 0	
    ${If} $R1 == $R2
      DetailPrint "$WINDIR\inf\$2 wird deinstalliert."
      !insertmacro ShellExecWait "" '"$INSTDIR\Treiber\instdrv.exe"' '"remove" "$INSTDIR\Treiber\AVRUSBBoot.inf" "USB\VID_16C0&PID_05DC"' "" ${SW_SHOWMINIMIZED}" $3
      !insertmacro ShellExecWait "" '"$INSTDIR\Treiber\instdrv.exe"' '"dp_delete" "$2"' "" ${SW_SHOWMINIMIZED}" $3
    ${EndIf}	
  done:   
  FindNext $1 $2
  FileClose $R0
  Goto loop  
  end:
  FindClose $1
  FindFirst $1 $2 "$WINDIR\inf\*.*"
  dirloop:
     IfErrors dirend 
     FindNext $1 $2
     goto dirloop
  dirend:
  FindClose $1
FunctionEnd


Function un.DeleteDriver
  FindFirst $1 $2 "$WINDIR\inf\oem*.inf"
  loop:
    IfErrors end
	StrCpy $R3 0
	FileOpen $R0 "$WINDIR\inf\$2" r
	Push $R0
	Call un.FileReadUnicode	
	Pop $R1
	IfErrors done
	StrCpy $R1 $R1 27 3
	StrCpy $R2 "micronucleus_bootloader.inf"
	StrCpy $R2 $R2 27 0	
    ${If} $R1 == $R2
      StrCpy $3 $2
	  StrLen $R3 $2
	  IntOp $R3 $R3 - 3
	  StrCpy $2 $2 $R3 0
	  StrCpy $4 "$2PNF"
	${EndIf}
	StrCpy $R1 $R1 14 0
	StrCpy $R2 "AVRUSBBoot.inf"
	StrCpy $R2 $R2 14 0	
    ${If} $R1 == $R2
	  StrCpy $3 $2
	  StrLen $R3 $2
	  IntOp $R3 $R3 - 3
	  StrCpy $2 $2 $R3 0
	  StrCpy $4 "$2PNF"	  
	${EndIf}
	done:   
  FileClose $R0
  ${If} $R3 > 0  
  DetailPrint "Lsche Treiberdateien ..."
  Delete $WINDIR\inf\$3
  Delete $WINDIR\inf\$4
  ${EndIf}
  FindNext $1 $2
  Goto loop  
  end:
  FindClose $1
  FindFirst $1 $2 "$WINDIR\inf\*.*"
  dirloop:
     IfErrors dirend 
     FindNext $1 $2
     goto dirloop
  dirend:
  FindClose $1  
FunctionEnd


;function Refresh Shell Icons

  ;http://nsis.sourceforge.net/archive/viewpage.php?pageid=202
  ;After changing file associations, you can call this macro to refresh the shell immediatly.
  ;It calls the shell32 function SHChangeNotify. This will force windows to reload your changes from the registry.
  !define SHCNE_ASSOCCHANGED 0x08000000
  !define SHCNF_IDLIST 0

  Function RefreshShellIcons
  ;By jerome tremblay - april 2003
  System::Call 'shell32.dll::SHChangeNotify(i, i, i, i) v \
  (${SHCNE_ASSOCCHANGED}, ${SHCNF_IDLIST}, 0, 0)'
  FunctionEnd

  
;Installer Sections
Section "Treiber"

${If} ${RunningX64}
  SetRegView 64
${Else}
  SetRegView 32  
${EndIf}

;disable install driver software from windows update
  
  WriteRegDWORD HKLM "SOFTWARE\Microsoft\Windows\CurrentVersion\DriverSearching" \
					 "SearchOrderConfig" 0x2

  DetailPrint "Hardware Wizard Online Update deaktiviert !"

;copy the files.
  SetShellVarContext all

  SetOutPath "$INSTDIR"
  File "microsoft public license.txt"
  SetOutPath "$INSTDIR\Treiber\amd64"
  File "Treiber\amd64\libusb0.sys"
  File "Treiber\amd64\libusb0.dll"
  SetOutPath "$INSTDIR\Treiber\x86"
  File "Treiber\x86\libusb0.sys"
  File "Treiber\x86\libusb0_x86.dll"
  SetOutPath "$INSTDIR\Treiber"
  File "Treiber\AVRUSBBoot.inf"
  File "Treiber\AVRUSBBoot.cat"
  File "Treiber\micronucleus_bootloader.inf"
  File "Treiber\micronucleus_bootloader.cat"
  
  SetOutPath "$INSTDIR\Treiber" 

${If} ${RunningX64}
  File "Treiber\amd64\instdrv.exe"
${Else}
  File "Treiber\x86\instdrv.exe"  
${EndIf}

;remove libusb driver
call RemoveDriver

;delete libusb driver
call DeleteDriver

;install the driver for the usb-board 
 !insertmacro ShellExecWait "" '"$INSTDIR\Treiber\instdrv.exe"' '"-r" "install" "$INSTDIR\Treiber\AVRUSBBoot.inf" "USB\VID_16C0&PID_05DC"' "" ${SW_SHOWMINIMIZED}" $1
 IntCmp $1 0 +2 0 
 Goto fail_01

scan_01:
;scan for device and wait
!insertmacro ShellExecWait "" '"$INSTDIR\Treiber\instdrv.exe"' '"remove" "USB\VID_16C0&PID_05DC"' "" ${SW_SHOWMINIMIZED}" $1
!insertmacro ShellExecWait "" '"$INSTDIR\Treiber\instdrv.exe"' '"rescan" "USB\VID_16C0&PID_05DC"' "" ${SW_SHOWMINIMIZED}" $1

;check if device is successfully plugged in
  nsExec::ExecToStack '"$INSTDIR\Treiber\instdrv.exe" "find" "USB\VID_16C0&PID_05DC"'
  Pop $0
  Pop $1
  ${StrContains} $0 "VID_16C0&PID_05DC" $1
  StrCmp $0 "" notfound_01
  Goto done_01
notfound_01:
  MessageBox MB_YESNO|MB_ICONQUESTION   "Das USB-Board wurde nicht gefunden !$\r$\nStecken Sie jetzt das USB-Kabel ein.$\r$\r$\nSoll erneut nach dem Gert gesucht werden ?"\
  IDNO cont_01
  ;!insertmacro ShellExecWait "" '"$INSTDIR\Treiber\instdrv.exe"' '"remove" "USB\VID_16C0&PID_05DC"' "" ${SW_SHOWMINIMIZED}" $1
  !insertmacro ShellExecWait "" '"$INSTDIR\Treiber\instdrv.exe"' '"rescan" "USB\VID_16C0&PID_05DC"' "" ${SW_SHOWMINIMIZED}" $1
  Goto scan_01
cont_01:
  MessageBox MB_OK "Die Installation wird fortgesetzt, sobald das USB-Board angeschlossen wird !"  
  Goto done_01
fail_01:
  MessageBox MB_ICONEXCLAMATION  "Der USB-Treiber fr das USB-Board wurde nicht installiert !"  

done_01:
;install the driver for the simon-board 
 !insertmacro ShellExecWait "" '"$INSTDIR\Treiber\instdrv.exe"' '"-r" "install" "$INSTDIR\Treiber\micronucleus_bootloader.inf" "USB\VID_16D0&PID_0753"' "" ${SW_SHOWMINIMIZED}" $1
 IntCmp $1 0 +2 0 
 Goto fail_02

scan_02:
;scan for device and wait
!insertmacro ShellExecWait "" '"$INSTDIR\Treiber\instdrv.exe"' '"remove" "USB\VID_16D0&PID_0753"' "" ${SW_SHOWMINIMIZED}" $1
!insertmacro ShellExecWait "" '"$INSTDIR\Treiber\instdrv.exe"' '"rescan" "USB\VID_16D0&PID_0753"' "" ${SW_SHOWMINIMIZED}" $1

;check if device is successfully plugged in
  nsExec::ExecToStack '"$INSTDIR\Treiber\instdrv.exe" "find" "USB\VID_16D0&PID_0753"'
  Pop $0
  Pop $1
  ${StrContains} $0 "VID_16D0&PID_0753" $1
  StrCmp $0 "" notfound_02
  Goto done_02
notfound_02:
  MessageBox MB_YESNO|MB_ICONQUESTION   "Das Simon-Board wurde nicht gefunden !$\r$\nStecken Sie jetzt das USB-Kabel ein.$\r$\r$\nSoll erneut nach dem Gert gesucht werden ?"\
  IDNO cont_02
  Goto scan_02
cont_02:
  MessageBox MB_OK "Die Installation wird fortgesetzt, sobald das Simon-Board angeschlossen wird !"  
  Goto done_02
fail_02:
  MessageBox MB_ICONEXCLAMATION  "Der USB-Treiber fr das Simon-Board wurde nicht installiert !"  
done_02:
;allways install the best driver software  
  WriteRegDWORD HKLM "SOFTWARE\Microsoft\Windows\CurrentVersion\DriverSearching" "SearchOrderConfig" 0x1

  DetailPrint "Hardware Wizard Online Update aktiviert !" 
  
SectionEnd


Section "Flashtool"

;copy the files.
  SetShellVarContext all
  SetOutPath "$INSTDIR"
  File "avrflashtool.exe"
  File "ampel.hex"
  File "blinker.hex"
  File "mario.hex"
  File "pacman.hex"
  File "tetris.hex"
  File "schach.hex"
  File "simon.hex"
  
;create shortcuts
  !insertmacro MUI_STARTMENU_WRITE_BEGIN Application

  CreateDirectory "$SMPROGRAMS\$StartMenuFolder"
  CreateShortCut "$SMPROGRAMS\$StartMenuFolder\Uninstall AVR-Flashtool.lnk" "$INSTDIR\uninstall.exe" "" "$INSTDIR\uninstall.exe" 0
  CreateShortCut "$SMPROGRAMS\$StartMenuFolder\AVR-Flashtool.lnk" "$INSTDIR\avrflashtool.exe" "" "$INSTDIR\avrflashtool.exe" 0
  CreateShortCut "$Desktop\AVR-Flashtool.lnk" "$INSTDIR\avrflashtool.exe"
  Call RefreshShellIcons

  !insertmacro MUI_STARTMENU_WRITE_END
  
;create the uninstaller
  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\AVR-Flashtool" "DisplayName" "AVR-Flashtool"
  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\AVR-Flashtool" "Publisher" "Dietrich Kindermann"
  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\AVR-Flashtool" "UninstallString" '"$INSTDIR\uninstall.exe"'
  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\AVR-Flashtool" "DisplayIcon" "$\"$INSTDIR\uninstall.exe$\",0"
  WriteRegDWORD HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\AVR-Flashtool" "NoModify" 1
  WriteRegDWORD HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\AVR-Flashtool" "NoRepair" 1
  WriteUninstaller "uninstall.exe"

SectionEnd

 
Section "Uninstall"

${If} ${RunningX64}
  SetRegView 64
${Else}
  SetRegView 32  
${EndIf}

  SetShellVarContext all
  
;remove libusb driver
  MessageBox MB_YESNO|MB_ICONQUESTION   "Soll der LibUSB-Treiber fr alle Gerte deinstalliert werden ?"\
  IDNO cont
  call un.RemoveDriver
  call un.DeleteDriver
cont:
  
;remove files  
  Delete $INSTDIR\Treiber\amd64\libusb0.dll
  Delete $INSTDIR\Treiber\amd64\libusb0.sys
  Delete $INSTDIR\Treiber\x86\libusb0_x86.dll
  Delete $INSTDIR\Treiber\x86\libusb0.sys
  Delete $INSTDIR\Treiber\instdrv.exe
  Delete $INSTDIR\Treiber\AVRUSBBoot.inf
  Delete $INSTDIR\Treiber\AVRUSBBoot.cat
  Delete $INSTDIR\Treiber\micronucleus_bootloader.inf
  Delete $INSTDIR\Treiber\micronucleus_bootloader.cat
  Delete $INSTDIR\uninstall.exe
  Delete $INSTDIR\avrflashtool.exe
  Delete $INSTDIR\ampel.hex
  Delete $INSTDIR\blinker.hex
  Delete $INSTDIR\mario.hex
  Delete $INSTDIR\pacman.hex
  Delete $INSTDIR\tetris.hex
  Delete $INSTDIR\schach.hex
  Delete $INSTDIR\simon.hex
  Delete "$INSTDIR\microsoft public license.txt"
  RMDir /r $INSTDIR\Treiber\amd64
  RMDir /r $INSTDIR\Treiber\x86
  RMDir /r $INSTDIR\Treiber  
  RMDir /r "$INSTDIR"
;remove shortcuts
  !insertmacro MUI_STARTMENU_GETFOLDER Application $StartMenuFolder

  Delete "$DESKTOP\AVR-Flashtool.lnk"
  Delete "$SMPROGRAMS\$StartMenuFolder\AVR-Flashtool.lnk"
  Delete "$SMPROGRAMS\$StartMenuFolder\Uninstall AVR-Flashtool.lnk"
  RMDir "$SMPROGRAMS\$StartMenuFolder"

;Remove registry keys
  DeleteRegKey HKLM "Software\AVR-Flashtool"
  DeleteRegKey HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\AVR-Flashtool"  
  
SectionEnd
